#!/bin/python3
# -*- coding: utf-8 -*-

import platform
import configparser
from pathlib import Path


class Config:
    try:
        config = configparser.ConfigParser()
        config.read('/etc/sbpkg/sbpkg.conf')

        # [REPOSITORY]
        repo_name: str = config['REPOSITORY']['name']
        repo_branch: str = config['REPOSITORY']['branch']
        repo_mirror: str = config['REPOSITORY']['mirror']
        local_repo: Path = Path(config['REPOSITORY']['local_repo'])
        changelog_txt: str = config['REPOSITORY']['changelog']
        slackbuilds_txt: str = config['REPOSITORY']['slackbuilds']
        repo_tag: str = config['REPOSITORY']['tag']
        pkgtype: str = config['REPOSITORY']['pkgtype']
        compressed: str = config['REPOSITORY']['compressed']
        gpg_archive: str = config['REPOSITORY']['gpg_archive']

        # [PATH]
        tmp: Path = Path(config['PATH']['tmp'])
        tmp_sbpkg_path: Path = Path(config['PATH']['tmp_sbpkg'])
        build_path: Path = Path(config['PATH']['build'])
        lib_path: Path = Path(config['PATH']['library'])
        log_path: Path = Path(config['PATH']['log'])
        log_pkgs_path: Path = Path(config['PATH']['packages'])
        etc_path: Path = Path(config['PATH']['etc'])
        download_path: Path = Path(config['PATH']['download'])

        # [RSYNC]
        rsync: str = 'rsync'
        rsync_options: str = config['RSYNC']['options']

        # [LFTP]
        lftp: str = 'lftp'
        lftp_options: str = config['LFTP']['options']

        # [WGET]
        wget: str = 'wget'
        wget_options: str = config['WGET']['options']

        # [SLACKWARE]
        install_command: str = config['SLACKWARE']['install']
        reinstall_command: str = config['SLACKWARE']['reinstall']
        remove_command: str = config['SLACKWARE']['remove']
        slack_pkgtype: str = config['SLACKWARE']['pkgtype']

        # [MISC]
        colors: str = config['MISC']['colors'].lower()
        progress_bar: str = config['MISC']['progress_bar'].lower()
        parallel_downloads: str = config['MISC']['parallel_downloads'].lower()
        maximum_parallel: int = config['MISC']['maximum_parallel']
        makeflags: str = config['MISC']['makeflags']
        pkglist_suffix: str = config['MISC']['pkglist_suffix']
        editor: str = config['MISC']['editor']
        gpg_verification: str = config['MISC']['gpg_verification'].lower()
        checksum_md5: str = config['MISC']['checksum_md5'].lower()
        no_confirm: str = config['MISC']['no_confirm'].lower()

    except KeyError as e:
        raise SystemExit(f'\nsbpkg: Error in the configuration file: {e}\n')

    # Settings outside to configparser.
    arch: str = platform.machine()
    json_data_file: Path = Path(lib_path, repo_name, repo_branch, 'data.json')
    log_file: Path = Path(log_path, 'sbpkg.log')
    deps_log_file: Path = Path(log_path, 'deps.log')
    upgrade_log_file: Path = Path(log_path, 'upgrade.log')
    blacklist_file: Path = Path(etc_path, 'blacklist')

    # Setting the colors.
    bold: str = ''
    black: str = ''
    green: str = ''
    cyan: str = ''
    red: str = ''
    yellow: str = ''
    grey: str = ''
    bgreen: str = ''
    bcyan: str = ''
    bred: str = ''
    byellow: str = ''
    white_bg: str = ''
    endc: str = ''

    if colors == 'on':
        bold: str = '\x1b[1m'
        black: str = '\x1b[30m'
        green: str = '\x1b[32m'
        cyan: str = '\x1b[96m'
        red: str = '\x1b[91m'
        yellow: str = '\x1b[93m'
        grey: str = '\x1b[38;5;247m'
        bgreen: str = f'{bold}{green}'
        bcyan: str = f'{bold}{cyan}'
        bred: str = f'{bold}{red}'
        byellow: str = f'{bold}{yellow}'
        white_bg: str = '\x1b[107m'
        endc: str = '\x1b[0m'
