#!/usr/bin/python3
# -*- coding: utf-8 -*-

# setup.py file is part of sbpkg.

# Copyright 2024 Dimitris Zlatanidis <dslackw@gmail.com>
# All rights reserved.

# https://gitlab.com/dslackw/sbpkg

# sbpkg is free software: you can redistribute it and/or
# modify it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.

from setuptools import setup
from sbpkg.metadata import Metadata

name: str = Metadata.__prgnam__
version: str = Metadata.__version__


setup(
    name=name,
    packages=[name],
    scripts=[f'bin/{name}'],
    version=version,
    description='Simple, fast and full-featured SBo package manager.',
    long_description=open('README.md').read(),
    keywords=['system', 'packaging', 'slackware', 'install', 'remove', 'slackbuild'],
    author='Dimitris Zlatanidis',
    author_email='dslackw@gmail.com',
    package_data={'': ['LICENSE.txt', 'README.md', 'ChangeLog.md']},
    url='https://gitlab.com/dslackw/sbpkg',
    classifiers=[
        'Development Status :: 4 - Beta',
        'License :: OSI Approved :: GNU General Public License v3 or later (GPLv3+)',
        'Operating System :: POSIX :: Linux',
        'Programming Language :: Python :: 3.9',
        'Topic :: Desktop Environment',
        'Topic :: System :: Monitoring',
        'Topic :: System :: Software Distribution',
        'Topic :: System :: Installation/Setup',
        'Topic :: System :: Systems Administration',
        'Topic :: System :: Software Distribution'
        ],
    python_requires='>=3.9'
)
